%                               -*- slang -*-
%                               
% example user initialization for jed-extra
% =========================================
% 
% If your system has the jed-extra package installed but you do not want to
% use it at all, you can revert the configuration as normal user,  if the
% sysadmin changed the default configuration in /etc/jed.d/50jed-extra.sl to
% the example 50jed-extra-minimal.sl.
%   
% In this case, you are invited to insert this file into your jed.rc and
% modify according to your needs.
%
% You can still copy or link individual modes to your personal jed library
% directory and activate according to the documentation in the source file.

% The jed-extra library dir
$1 = "/usr/share/jed/jed-extra/";

% remove library directories from the search path
% -----------------------------------------------

% The default setup in /etc/jed.d/50jed-extra.sl adds library directories
% for normal modes, utilities, and drop-in modes.

% Utilities (required by the other modes)
remove_libdir($1 + "utils/");  % you could keep this without major impact
% re-append documentation for "util functions" to the online help
% Jed_Doc_Files += "," + $1+"utils/libfuns.txt";

% "Normal" modes
%   Initialization is done in the default config (but not in minimal)
%   (check /etc/jed.d/50jed-extra*.sl)
remove_libdir($1);  % keep this if you tolerate slightly longer searching
% re-append documentation to the online help
% Jed_Doc_Files += "," + $1+"libfuns.txt";

% Drop-In Modes (recent, help, man, ...) need to be prepended
%   Initialization is low key (autolaods for additional functions)
remove_libdir($1+"drop-in/") % remove to use the standard versions
% re-append documentation for drop-in modes to the online help
% Jed_Doc_Files += "," + $1+"drop-in/libfuns.txt";

% Experimental and exotic modes
% normally not activated
% remove_libdir($1+"extra/")
% 
%   Recommended use is to copy or link interesting modes
%   to /usr/local/share/jed/lib/ or ~/.jed/lib 
%   and use make_ini() and add_libdir() for activation (see below)
 
% add documentation for "extra functions" to the online help
% Jed_Doc_Files += "," + $1+"extra/libfuns.txt";


% Jed_Home_Directory and private extensions
% -----------------------------------------

% User extensions
%   Debian sets Jed_Home_Directory to ~/.jed/ if this dir exists
% add_libdir(path_concat(Jed_Home_Directory, "lib"), 1);
% Jed_Highlight_Cache_Dir = path_concat(Jed_Home_Directory, "lib");

% Site wide extensions
% add_libdir("/usr/local/share/jed/lib/", 1);
